@@ -1,33 +1,32 @@
 """
 The code in this module is basically a copy of
-http://docs.astropy.org/en/stable/_modules/astropy/coordinates/builtin_frames/skyoffset.html
+https://docs.astropy.org/en/stable/_modules/astropy/coordinates/builtin_frames/skyoffset.html
 
 We are just not creating a metaclass and a factory but directly building the
 corresponding class.
 """
 import astropy.units as u
-from astropy.coordinates.matrix_utilities import (
-    rotation_matrix,
-    matrix_product,
-    matrix_transpose,
-)
 from astropy.coordinates import (
-    frame_transform_graph,
-    FunctionTransform,
-    DynamicMatrixTransform,
+    AltAz,
+    Angle,
     BaseCoordinateFrame,
     CoordinateAttribute,
-    TimeAttribute,
+    DynamicMatrixTransform,
     EarthLocationAttribute,
+    FunctionTransform,
     RepresentationMapping,
+    TimeAttribute,
     UnitSphericalRepresentation,
-    Angle,
-    AltAz,
+    frame_transform_graph,
 )
+from astropy.coordinates.matrix_utilities import matrix_transpose, rotation_matrix
 
 __all__ = ["TelescopeFrame"]
 
 
+_wrap_angle = Angle(180, unit=u.deg)
+
+
 class TelescopeFrame(BaseCoordinateFrame):
     """
     Telescope coordinate frame.
@@ -73,11 +72,11 @@ class TelescopeFrame(BaseCoordinateFrame):
 
         # make sure telescope coordinate is in range [-180°, 180°]
         if isinstance(self._data, UnitSphericalRepresentation):
-            self._data.lon.wrap_angle = Angle(180, unit=u.deg)
+            self._data.lon.wrap_angle = _wrap_angle
 
 
 @frame_transform_graph.transform(FunctionTransform, TelescopeFrame, TelescopeFrame)
-def skyoffset_to_skyoffset(from_telescope_coord, to_telescope_frame):
+def telescope_to_telescope(from_telescope_coord, to_telescope_frame):
     """Transform between two skyoffset frames."""
 
     intermediate_from = from_telescope_coord.transform_to(
@@ -90,22 +89,24 @@ def skyoffset_to_skyoffset(from_telescope_coord, to_telescope_frame):
 
 
 @frame_transform_graph.transform(DynamicMatrixTransform, AltAz, TelescopeFrame)
-def reference_to_skyoffset(reference_frame, telescope_frame):
+def altaz_to_telescope(altaz_coord, telescope_frame):
     """Convert a reference coordinate to an sky offset frame."""
 
     # Define rotation matrices along the position angle vector, and
     # relative to the telescope_pointing.
-    telescope_pointing = telescope_frame.telescope_pointing.spherical
+    telescope_pointing = telescope_frame.telescope_pointing.represent_as(
+        UnitSphericalRepresentation
+    )
     mat1 = rotation_matrix(-telescope_pointing.lat, "y")
     mat2 = rotation_matrix(telescope_pointing.lon, "z")
-    return matrix_product(mat1, mat2)
+    return mat1 @ mat2
 
 
 @frame_transform_graph.transform(DynamicMatrixTransform, TelescopeFrame, AltAz)
-def skyoffset_to_reference(skyoffset_coord, reference_frame):
+def telescope_to_altaz(telescope_coord, altaz_frame):
     """Convert an sky offset frame coordinate to the reference frame"""
 
     # use the forward transform, but just invert it
-    mat = reference_to_skyoffset(reference_frame, skyoffset_coord)
+    mat = altaz_to_telescope(altaz_frame, telescope_coord)
     # transpose is the inverse because mat is a rotation matrix
     return matrix_transpose(mat)
