@@ -1,17 +1,17 @@
 """ Class to handle configuration for algorithms """
+import warnings
+import weakref
 from abc import ABCMeta
-from inspect import isabstract
+from inspect import cleandoc, isabstract
 from logging import getLogger
-from docutils.core import publish_parts
-from inspect import cleandoc
 
+from docutils.core import publish_parts
 from traitlets import TraitError
 from traitlets.config import Configurable
 
-import warnings
+from .plugins import detect_and_import_plugins
 
-
-__all__ = ["non_abstract_children", "Component", "TelescopeComponent"]
+__all__ = ["non_abstract_children", "Component"]
 
 
 def find_config_in_hierarchy(parent, class_name, trait_name):
@@ -72,7 +72,7 @@ def non_abstract_children(base):
 class AbstractConfigurableMeta(type(Configurable), ABCMeta):
     """
     Metaclass to be able to make Component abstract
-    see: http://stackoverflow.com/a/7314847/3838691
+    see: https://stackoverflow.com/a/7314847/3838691
     """
 
     pass
@@ -158,6 +158,8 @@ class Component(Configurable, metaclass=AbstractConfigurableMeta):
         with warnings.catch_warnings():
             warnings.filterwarnings("error", message=".*Config option.*not recognized")
             try:
+                if parent is not None:
+                    parent = weakref.proxy(parent)
                 super().__init__(parent=parent, config=config, **kwargs)
             except UserWarning as e:
                 raise TraitError(e) from None
@@ -201,6 +203,9 @@ class Component(Configurable, metaclass=AbstractConfigurableMeta):
         get dict{name: cls} of non abstract subclasses,
         subclasses can possibly be definded in plugins
         """
+        if hasattr(cls, "plugin_entry_point"):
+            detect_and_import_plugins(cls.plugin_entry_point)
+
         subclasses = {base.__name__: base for base in non_abstract_children(cls)}
         return subclasses
 
@@ -262,54 +267,9 @@ class Component(Configurable, metaclass=AbstractConfigurableMeta):
         lines.append("</div>")
         return "\n".join(lines)
 
-
-class TelescopeComponent(Component):
-    """
-    A component that needs a `~ctapipe.instrument.SubarrayDescription` to be constructed,
-    and which contains configurable `~ctapipe.core.traits.TelescopeParameter` fields
-    that must be configured on construction.
-    """
-
-    def __init__(self, subarray, config=None, parent=None, **kwargs):
-        super().__init__(config, parent, **kwargs)
-
-        self.subarray = subarray
-        # configure all of the TelescopeParameters
-        for trait in list(self.class_traits()):
-            try:
-                getattr(self, trait).attach_subarray(subarray)
-            except (AttributeError, TypeError):
-                pass
-
-    @classmethod
-    def from_name(cls, name, subarray, config=None, parent=None, **kwargs):
-        """
-        Obtain an instance of a subclass via its name
-
-        Parameters
-        ----------
-        name : str
-            Name of the subclass to obtain
-        subarray: ctapipe.instrument.SubarrayDescription
-            The current subarray for this TelescopeComponent.
-        config : traitlets.loader.Config
-            Configuration specified by config file or cmdline arguments.
-            Used to set traitlet values.
-            This argument is typically only specified when using this method
-            from within a Tool.
-        parent : ctapipe.core.Tool
-            Tool executable that is calling this component.
-            Passes the correct logger and configuration to the component.
-            This argument is typically only specified when using this method
-            from within a Tool (config need not be passed if parent is used).
-        kwargs
-
-        Returns
-        -------
-        instace
-            Instance of subclass to this class
-        """
-        requested_subclass = cls.non_abstract_subclasses()[name]
-        return requested_subclass(
-            subarray=subarray, config=config, parent=parent, **kwargs
-        )
+    def __getstate__(self):
+        """Make Components pickle-able by removing non-pickleable members"""
+        state = self.__dict__.copy()
+        state["_trait_values"]["parent"] = None
+        state["_trait_notifiers"] = {}
+        return state
