@@ -7,6 +7,8 @@ from typing import Dict, Generator, List, Tuple
 
 from traitlets.config.loader import LazyConfigValue
 
+from ctapipe.atmosphere import AtmosphereDensityProfile
+
 from ..containers import (
     ArrayEventContainer,
     ObservationBlockContainer,
@@ -14,7 +16,7 @@ from ..containers import (
     SimulationConfigContainer,
 )
 from ..core import Provenance, ToolConfigurationError
-from ..core.component import Component, find_config_in_hierarchy, non_abstract_children
+from ..core.component import Component, find_config_in_hierarchy
 from ..core.traits import CInt, Int, Path, Set, TraitError, Undefined
 from ..instrument import SubarrayDescription
 from .datalevels import DataLevel
@@ -70,11 +72,8 @@ class EventSource(Component):
     0
     1
 
-    **NOTE**: For effiency reasons, most sources only use a single ``ArrayEvent`` instance
-    and update it with new data on iteration, which might lead to surprising
-    behaviour if you want to access multiple events at the same time.
-    To keep an event and prevent its data from being overwritten with the next event's data,
-    perform a deepcopy: ``some_special_event = copy.deepcopy(event)``.
+    **NOTE**: EventSource implementations should not reuse the same ArrayEventContainer,
+    as these are mutable and may lead to errors when analyzing multiple events.
 
 
     Attributes
@@ -89,6 +88,9 @@ class EventSource(Component):
         generated events. If None, all available telescopes are used.
     """
 
+    #: ctapipe_io entry points may provide EventSource implementations
+    plugin_entry_point = "ctapipe_io"
+
     input_url = Path(help="Path to the input file containing events.").tag(config=True)
 
     max_events = Int(
@@ -283,6 +285,20 @@ class EventSource(Component):
         """
         return list(self.observation_blocks.keys())
 
+    @property
+    def atmosphere_density_profile(self) -> AtmosphereDensityProfile:
+        """atmosphere density profile that can be integrated to
+        convert between h_max and X_max.  This should correspond
+        either to what was used in a simualtion, or a measurment
+        for use with observed data.
+
+        Returns
+        -------
+        AtmosphereDensityProfile:
+           profile to be used
+        """
+        return None
+
     @abstractmethod
     def _generator(self) -> Generator[ArrayEventContainer, None, None]:
         """
@@ -324,14 +340,14 @@ class EventSource(Component):
         # to make sure it's compatible and to raise the correct error
         input_url = EventSource.input_url.validate(obj=None, value=input_url)
 
-        available_classes = non_abstract_children(cls)
+        available_classes = cls.non_abstract_subclasses()
 
-        for subcls in available_classes:
+        for name, subcls in available_classes.items():
             try:
                 if subcls.is_compatible(input_url):
                     return subcls
             except Exception as e:
-                warnings.warn(f"{subcls.__name__}.is_compatible raised exception: {e}")
+                warnings.warn(f"{name}.is_compatible raised exception: {e}")
 
         # provide a more helpful error for non-existing input_url
         if not input_url.exists():
@@ -344,7 +360,7 @@ class EventSource(Component):
             "Cannot find compatible EventSource for \n"
             "\turl:{}\n"
             "in available EventSources:\n"
-            "\t{}".format(input_url, [c.__name__ for c in available_classes])
+            "\t{}".format(input_url, [c for c in available_classes])
         )
 
     @classmethod
