@@ -2,13 +2,14 @@
 Class and related functions to read DL1 (a,b) and/or DL2 (a) data
 from an HDF5 file produced with ctapipe-process.
 """
-from collections import defaultdict
+import warnings
+from collections import defaultdict, namedtuple
 from pathlib import Path
 from typing import Dict
 
 import numpy as np
 import tables
-from astropy.table import Table, vstack
+from astropy.table import Table, hstack, vstack
 from astropy.utils.decorators import lazyproperty
 
 from ctapipe.instrument.optics import FocalLengthKind
@@ -21,6 +22,7 @@ __all__ = ["TableLoader"]
 
 PARAMETERS_GROUP = "/dl1/event/telescope/parameters"
 IMAGES_GROUP = "/dl1/event/telescope/images"
+MUON_GROUP = "/dl1/event/telescope/muon"
 TRIGGER_TABLE = "/dl1/event/subarray/trigger"
 SHOWER_TABLE = "/simulation/event/subarray/shower"
 TRUE_IMAGES_GROUP = "/simulation/event/telescope/images"
@@ -28,6 +30,7 @@ TRUE_PARAMETERS_GROUP = "/simulation/event/telescope/parameters"
 TRUE_IMPACT_GROUP = "/simulation/event/telescope/impact"
 SIMULATION_CONFIG_TABLE = "/configuration/simulation/run"
 SHOWER_DISTRIBUTION_TABLE = "/simulation/service/shower_distribution"
+OBSERVATION_TABLE = "/configuration/observation/observation_block"
 
 DL2_SUBARRAY_GROUP = "/dl2/event/subarray"
 DL2_TELESCOPE_GROUP = "/dl2/event/telescope"
@@ -36,6 +39,13 @@ SUBARRAY_EVENT_KEYS = ["obs_id", "event_id"]
 TELESCOPE_EVENT_KEYS = ["obs_id", "event_id", "tel_id"]
 
 
+Chunk = namedtuple("Chunk", ["start", "stop", "data"])
+
+
+class IndexNotMatching(UserWarning):
+    """Warning that is raised if the order of two tables is not matching as expected"""
+
+
 class ChunkIterator:
     """An iterator that calls a function on advancemnt
 
@@ -58,13 +68,12 @@ class ChunkIterator:
         func,
         n_total,
         chunk_size,
-        *args,
-        **kwargs,
+        args,
+        kwargs,
     ):
         self.func = func
         self.n_total = n_total
         self.chunk_size = chunk_size
-        self._current_chunk = 0
         self.n_chunks = int(np.ceil(self.n_total / self.chunk_size))
         self.args = args
         self.kwargs = kwargs
@@ -72,20 +81,22 @@ class ChunkIterator:
     def __len__(self):
         return self.n_chunks
 
-    def __iter__(self):
-        self._current_chunk = 0
-        return self
+    def __getitem__(self, chunk):
 
-    def __next__(self):
-        if self._current_chunk == self.n_chunks:
-            raise StopIteration
+        if chunk < 0:
+            chunk = self.n_chunks - chunk
+
+        if chunk >= self.n_chunks:
+            raise IndexError(
+                f"Index {chunk} is out of bounds for {self.__class__.__name__}"
+                f" of length {len(self)}"
+            )
 
-        chunk = self._current_chunk
         start = chunk * self.chunk_size
         stop = min(self.n_total, (chunk + 1) * self.chunk_size)
-
-        self._current_chunk += 1
-        return self.func(*self.args, start=start, stop=stop, **self.kwargs)
+        return Chunk(
+            start, stop, self.func(*self.args, start=start, stop=stop, **self.kwargs)
+        )
 
 
 def _empty_telescope_events_table():
@@ -93,7 +104,7 @@ def _empty_telescope_events_table():
     Create a new astropy table with correct column names and dtypes
     for telescope event based data.
     """
-    return Table(names=TELESCOPE_EVENT_KEYS, dtype=[np.int32, np.int64, np.int16])
+    return Table(names=TELESCOPE_EVENT_KEYS, dtype=[np.uint64, np.uint64, np.uint16])
 
 
 def _join_subarray_events(table1, table2):
@@ -112,6 +123,32 @@ def _join_telescope_events(table1, table2):
     return join_allow_empty(table1, table2, TELESCOPE_EVENT_KEYS, how)
 
 
+def _merge_table_same_index(table1, table2, index_keys, fallback_join_type="left"):
+    """Merge two tables assuming their primary keys are identical"""
+    if len(table1) != len(table2):
+        raise ValueError("Tables must have identical length")
+
+    if len(table1) == 0:
+        return table1
+
+    if not np.all(table1[index_keys] == table2[index_keys]):
+        warnings.warn(
+            "Table order does not match, falling back to join", IndexNotMatching
+        )
+        return join_allow_empty(table1, table2, index_keys, fallback_join_type)
+
+    columns = [col for col in table2.columns if col not in index_keys]
+    return hstack((table1, table2[columns]), join_type="exact")
+
+
+def _merge_subarray_tables(table1, table2):
+    return _merge_table_same_index(table1, table2, SUBARRAY_EVENT_KEYS)
+
+
+def _merge_telescope_tables(table1, table2):
+    return _merge_table_same_index(table1, table2, TELESCOPE_EVENT_KEYS)
+
+
 class TableLoader(Component):
     """
     Load telescope-event or subarray-event data from ctapipe HDF5 files
@@ -143,6 +180,9 @@ class TableLoader(Component):
     load_dl1_parameters = traits.Bool(
         True, help="load reconstructed image parameters"
     ).tag(config=True)
+    load_dl1_muons = traits.Bool(False, help="load muon ring parameters").tag(
+        config=True
+    )
 
     load_dl2 = traits.Bool(False, help="load available dl2 stereo parameters").tag(
         config=True
@@ -162,15 +202,20 @@ class TableLoader(Component):
         False, help="join subarray instrument information to each event"
     ).tag(config=True)
 
+    load_observation_info = traits.Bool(
+        False, help="join observation information to each event"
+    ).tag(config=True)
+
     focal_length_choice = traits.UseEnum(
         FocalLengthKind,
         default_value=FocalLengthKind.EFFECTIVE,
         help=(
             "If both nominal and effective focal lengths are available, "
-            " which one to use for the `CameraFrame` attached"
-            " to the `CameraGeometry` instances in the `SubarrayDescription`"
-            ", which will be used in CameraFrame to TelescopeFrame coordinate"
-            " transforms. The 'nominal' focal length is the one used during "
+            " which one to use for the `~ctapipe.coordinates.CameraFrame` attached"
+            " to the `~ctapipe.instrument.CameraGeometry` instances in the"
+            " `ctapipe.instrument.SubarrayDescription`, which will be used in"
+            " CameraFrame to TelescopeFrame coordinate transforms."
+            " The 'nominal' focal length is the one used during "
             " the simulation, the 'effective' focal length is computed using specialized "
             " ray-tracing from a point light source"
         ),
@@ -206,6 +251,19 @@ class TableLoader(Component):
         if self.load_instrument:
             self.instrument_table = self.subarray.to_table("joined")
 
+        groups = {
+            "load_dl1_parameters": PARAMETERS_GROUP,
+            "load_dl1_images": IMAGES_GROUP,
+            "load_true_parameters": TRUE_PARAMETERS_GROUP,
+            "load_true_images": TRUE_IMAGES_GROUP,
+        }
+        for attr, group in groups.items():
+            if getattr(self, attr) and group not in self.h5file.root:
+                self.log.info(
+                    "Setting %s to False, input file does not contain such data", attr
+                )
+                setattr(self, attr, False)
+
     def close(self):
         """Close the underlying hdf5 file"""
         if self._should_close:
@@ -278,6 +336,34 @@ class TableLoader(Component):
         """
         return read_table(self.h5file, SHOWER_DISTRIBUTION_TABLE)
 
+    def read_observation_information(self):
+        """
+        Read the observation information
+        """
+        return read_table(self.h5file, OBSERVATION_TABLE)
+
+    def _join_observation_info(self, table):
+        obs_table = self.read_observation_information()
+        # in v0.17, obs_id had inconsistent dtypes in different tables
+        # Joining then gets messed up then because a join between int32 and uint64
+        # casts the obs_id in the joint result to float.
+        obs_table["obs_id"] = obs_table["obs_id"].astype(table["obs_id"].dtype)
+
+        # to be able to sort to original table order
+        self._add_index_if_needed(table)
+
+        joint = join_allow_empty(
+            table,
+            obs_table,
+            keys="obs_id",
+            join_type="left",
+        )
+
+        # sort back to original order and remove index col
+        self._sort_to_original_order(joint)
+        del table["__index__"]
+        return joint
+
     def read_subarray_events(self, start=None, stop=None, keep_order=True):
         """Read subarray-based event information.
 
@@ -292,7 +378,7 @@ class TableLoader(Component):
 
         if self.load_simulated and SHOWER_TABLE in self.h5file:
             showers = read_table(self.h5file, SHOWER_TABLE, start=start, stop=stop)
-            table = _join_subarray_events(table, showers)
+            table = _merge_subarray_tables(table, showers)
 
         if self.load_dl2:
             if DL2_SUBARRAY_GROUP in self.h5file:
@@ -307,13 +393,16 @@ class TableLoader(Component):
                             start=start,
                             stop=stop,
                         )
-                        table = _join_subarray_events(table, dl2)
+                        table = _merge_subarray_tables(table, dl2)
+
+        if self.load_observation_info:
+            table = self._join_observation_info(table)
 
         if keep_order:
             self._sort_to_original_order(table)
         return table
 
-    def read_subarray_events_chunked(self, chunk_size):
+    def read_subarray_events_chunked(self, chunk_size, *args, **kwargs):
         """
         Iterate over chunks of subarray events.
 
@@ -326,6 +415,8 @@ class TableLoader(Component):
             self.read_subarray_events,
             n_total=len(self),
             chunk_size=chunk_size,
+            args=args,
+            kwargs=kwargs,
         )
 
     def _read_telescope_events_for_id(self, tel_id, start=None, stop=None):
@@ -338,9 +429,9 @@ class TableLoader(Component):
         tel_id: int
             Telescope identification number.
         start: int
-            First row to read
+            First subarray event index to read
         stop: int
-            Last row to read (non-inclusive)
+            Last subarray event index to read
 
         Returns
         -------
@@ -350,19 +441,45 @@ class TableLoader(Component):
         if tel_id is None:
             raise ValueError("Please, specify a telescope ID.")
 
-        table = _empty_telescope_events_table()
+        # trigger is stored in a single table for all telescopes, we need to
+        # calculate the range to read from the stereo trigger info
+        trigger_start = trigger_stop = None
+        tel_start = tel_stop = None
+
+        if start is not None or stop is not None:
+            tel_start, tel_stop = self._get_tel_start_stop(tel_id, start, stop)
+
+        if start is not None:
+            trigger_start = self._n_total_telescope_events[start]
+
+        if stop is not None:
+            trigger_stop = self._n_total_telescope_events[stop]
+
+        table = read_table(
+            self.h5file,
+            "/dl1/event/telescope/trigger",
+            condition=f"tel_id == {tel_id}",
+            start=trigger_start,
+            stop=trigger_stop,
+        )
 
         if self.load_dl1_parameters:
             parameters = self._read_telescope_table(
-                PARAMETERS_GROUP, tel_id, start=start, stop=stop
+                PARAMETERS_GROUP, tel_id, start=tel_start, stop=tel_stop
             )
-            table = _join_telescope_events(table, parameters)
+            table = _merge_telescope_tables(table, parameters)
+
+        if self.load_dl1_muons:
+            muon_parameters = self._read_telescope_table(
+                MUON_GROUP, tel_id, start=tel_start, stop=tel_stop
+            )
+            table = _merge_telescope_tables(table, muon_parameters)
 
         if self.load_dl1_images:
             images = self._read_telescope_table(
-                IMAGES_GROUP, tel_id, start=start, stop=stop
+                IMAGES_GROUP, tel_id, start=tel_start, stop=tel_stop
             )
-            table = _join_telescope_events(table, images)
+            table = _merge_telescope_tables(table, images)
 
         if self.load_dl2:
             if DL2_TELESCOPE_GROUP in self.h5file:
@@ -374,19 +491,22 @@ class TableLoader(Component):
                     for algorithm in group._v_children:
                         path = f"{group_path}/{algorithm}"
                         dl2 = self._read_telescope_table(
-                            path, tel_id, start=start, stop=stop
+                            path, tel_id, start=tel_start, stop=tel_stop
                         )
-                        table = _join_telescope_events(table, dl2)
+                        if len(dl2) == 0:
+                            continue
+
+                        table = _merge_telescope_tables(table, dl2)
 
         if self.load_true_images:
             true_images = self._read_telescope_table(
-                TRUE_IMAGES_GROUP, tel_id, start=start, stop=stop
+                TRUE_IMAGES_GROUP, tel_id, start=tel_start, stop=tel_stop
             )
-            table = _join_telescope_events(table, true_images)
+            table = _merge_telescope_tables(table, true_images)
 
         if self.load_true_parameters:
             true_parameters = self._read_telescope_table(
-                TRUE_PARAMETERS_GROUP, tel_id, start=start, stop=stop
+                TRUE_PARAMETERS_GROUP, tel_id, start=tel_start, stop=tel_stop
             )
             table = _join_telescope_events(table, true_parameters)
 
@@ -399,56 +519,51 @@ class TableLoader(Component):
             impacts = self._read_telescope_table(
                 TRUE_IMPACT_GROUP,
                 tel_id,
-                start=start,
-                stop=stop,
+                start=tel_start,
+                stop=tel_stop,
             )
             table = _join_telescope_events(table, impacts)
 
         return table
 
-    def _read_telescope_events_for_ids(self, tel_ids, tel_start=None, tel_stop=None):
-        tel_start = tel_start if tel_start is not None else [None] * len(tel_ids)
-        tel_stop = tel_stop if tel_stop is not None else [None] * len(tel_ids)
-
-        tables = []
-        for tel_id, start, stop in zip(tel_ids, tel_start, tel_stop):
-            # no events for this telescope in chunk
-            if start is not None and stop is not None and (stop - start) == 0:
-                continue
-
-            tables.append(
-                self._read_telescope_events_for_id(tel_id, start=start, stop=stop)
-            )
-
+    def _read_telescope_events_for_ids(self, tel_ids, start=None, stop=None):
+        tables = [
+            self._read_telescope_events_for_id(tel_id, start=start, stop=stop)
+            for tel_id in tel_ids
+        ]
         return vstack(tables)
 
-    def _join_subarray_info(self, table, start=None, stop=None):
-        subarray_events = self.read_subarray_events(
-            start=start,
-            stop=stop,
-            keep_order=False,
-        )
+    def _join_subarray_info(self, table, start=None, stop=None, subarray_events=None):
+        if subarray_events is None:
+            subarray_events = self.read_subarray_events(
+                start=start,
+                stop=stop,
+                keep_order=False,
+            )
         table = join_allow_empty(
-            table, subarray_events, keys=SUBARRAY_EVENT_KEYS, join_type="left"
+            table,
+            subarray_events,
+            keys=SUBARRAY_EVENT_KEYS,
+            join_type="left",
+            # add suffix mono on duplicated columns, avoid underscore for stereo
+            table_names=["_mono", ""],
+            uniq_col_name="{col_name}{table_name}",
         )
         return table
 
-    def _get_tel_start_stop(self, tel_ids, start, stop):
+    def _get_tel_start_stop(self, tel_id, start, stop):
         tel_start = None
         tel_stop = None
-        if start is not None or stop is not None:
+        index = self.subarray.tel_ids_to_indices(tel_id)[0]
 
-            indices = self.subarray.tel_ids_to_indices(tel_ids)
+        # find first/last row for each telescope
+        if start is not None:
+            tel_start = self._n_telescope_events[start, index]
 
-            # find first/last row for each telescope
-            if start is not None:
-                tel_start = self._n_telescope_events[start][indices]
-
-            if stop is not None:
-                if stop >= len(self._n_telescope_events):
-                    tel_stop = None
-                else:
-                    tel_stop = self._n_telescope_events[stop][indices]
+        if stop is None or stop >= len(self._n_telescope_events):
+            tel_stop = None
+        else:
+            tel_stop = self._n_telescope_events[stop, index]
 
         return tel_start, tel_stop
 
@@ -486,8 +601,7 @@ class TableLoader(Component):
         else:
             tel_ids = self.subarray.get_tel_ids(telescopes)
 
-        tel_start, tel_stop = self._get_tel_start_stop(tel_ids, start, stop)
-        table = self._read_telescope_events_for_ids(tel_ids, tel_start, tel_stop)
+        table = self._read_telescope_events_for_ids(tel_ids, start, stop)
         table = self._join_subarray_info(table, start=start, stop=stop)
 
         # sort back to order in the file
@@ -498,7 +612,7 @@ class TableLoader(Component):
 
         return table
 
-    def read_telescope_events_chunked(self, chunk_size, **kwargs):
+    def read_telescope_events_chunked(self, chunk_size, *args, **kwargs):
         """
         Iterate over chunks of telescope events.
 
@@ -515,7 +629,8 @@ class TableLoader(Component):
             self.read_telescope_events,
             n_total=len(self),
             chunk_size=chunk_size,
-            **kwargs,
+            args=args,
+            kwargs=kwargs,
         )
 
     @lazyproperty
@@ -537,6 +652,14 @@ class TableLoader(Component):
         np.cumsum(tels_with_trigger, out=tels_with_trigger, axis=0)
         return tels_with_trigger
 
+    @lazyproperty
+    def _n_total_telescope_events(self):
+        """
+        Number of telescope events in the file for each telescope previous
+        to the nth subarray event.
+        """
+        return self._n_telescope_events.sum(axis=1)
+
     def read_telescope_events_by_type(
         self, telescopes=None, start=None, stop=None
     ) -> Dict[str, Table]:
@@ -559,37 +682,30 @@ class TableLoader(Component):
         else:
             tel_ids = self.subarray.get_tel_ids(telescopes)
 
-        tel_start, tel_stop = self._get_tel_start_stop(tel_ids, start, stop)
-        tel_start = tel_start if tel_start is not None else [None] * len(tel_ids)
-        tel_stop = tel_stop if tel_stop is not None else [None] * len(tel_ids)
+        subarray_events = self.read_subarray_events(
+            start=start, stop=stop, keep_order=False
+        )
+        self._add_index_if_needed(subarray_events)
 
         by_type = defaultdict(list)
-        sort_index = self._get_sort_index(start=start, stop=stop)
-
-        for tel_id, start, stop in zip(tel_ids, tel_start, tel_stop):
-            # no events for this telescope in range start/stop
-            if start is not None and stop is not None and (stop - start) == 0:
-                continue
-
+        for tel_id in tel_ids:
             key = str(self.subarray.tel[tel_id])
-            by_type[key].append(
-                self._read_telescope_events_for_id(tel_id, start=start, stop=stop)
-            )
+            table = self._read_telescope_events_for_id(tel_id, start=start, stop=stop)
+            if len(table) > 0:
+                by_type[key].append(table)
 
         by_type = {k: vstack(ts) for k, ts in by_type.items()}
-
         for key in by_type.keys():
             by_type[key] = self._join_subarray_info(
-                by_type[key], start=start, stop=stop
+                by_type[key], subarray_events=subarray_events
             )
-            by_type[key] = _join_subarray_events(by_type[key], sort_index)
             self._sort_to_original_order(by_type[key], include_tel_id=True)
 
         return by_type
 
-    def read_telescope_events_by_type_chunked(self, chunk_size, **kwargs):
+    def read_telescope_events_by_type_chunked(self, chunk_size, *args, **kwargs):
         """
-        Iterate over chunks of telescope events.
+        Iterate over chunks of telescope events as dicts of telescope type to tables.
 
         Parameters
         ----------
@@ -604,5 +720,69 @@ class TableLoader(Component):
             self.read_telescope_events_by_type,
             n_total=len(self),
             chunk_size=chunk_size,
-            **kwargs,
+            args=args,
+            kwargs=kwargs,
+        )
+
+    def read_telescope_events_by_id(
+        self, telescopes=None, start=None, stop=None
+    ) -> Dict[int, Table]:
+        """Read telescope-based event information.
+
+        Parameters
+        ----------
+        telescopes: List[Union[int, str, TelescopeDescription]]
+            Any list containing a combination of telescope IDs or telescope_descriptions.
+
+        Returns
+        -------
+        tables: dict(astropy.io.Table)
+            Dictionary of tables organized by telescope ids
+            Table with primary index columns "obs_id", "event_id" and "tel_id".
+        """
+
+        if telescopes is None:
+            tel_ids = tuple(self.subarray.tel.keys())
+        else:
+            tel_ids = self.subarray.get_tel_ids(telescopes)
+
+        subarray_events = self.read_subarray_events(
+            start=start, stop=stop, keep_order=False
+        )
+        self._add_index_if_needed(subarray_events)
+
+        by_id = {}
+        for tel_id in tel_ids:
+            # no events for this telescope in range start/stop
+            table = self._read_telescope_events_for_id(tel_id, start=start, stop=stop)
+            if len(table) > 0:
+                by_id[tel_id] = table
+
+        for tel_id in by_id.keys():
+            by_id[tel_id] = self._join_subarray_info(
+                by_id[tel_id], subarray_events=subarray_events
+            )
+            self._sort_to_original_order(by_id[tel_id], include_tel_id=False)
+
+        return by_id
+
+    def read_telescope_events_by_id_chunked(self, chunk_size, *args, **kwargs):
+        """
+        Iterate over chunks of telescope events and return a dict of one table per telescope id.
+
+        Parameters
+        ----------
+        chunk_size: int
+            Number of subarray events to load per chunk.
+            The telescope tables might be larger or smaller than chunk_size
+            depending on the selected telescopes.
+
+        *args, **kwargs are passed to `read_telescope_events_by_id`
+        """
+        return ChunkIterator(
+            self.read_telescope_events_by_id,
+            n_total=len(self),
+            chunk_size=chunk_size,
+            args=args,
+            kwargs=kwargs,
         )
