@@ -1,3 +1,5 @@
+""" tests of SimTelEventSource """
+# pylint: disable=import-outside-toplevel
 import copy
 from itertools import zip_longest
 from pathlib import Path
@@ -5,7 +7,7 @@ from pathlib import Path
 import astropy.units as u
 import numpy as np
 import pytest
-from astropy.coordinates import Angle
+from astropy.coordinates import Angle, Latitude
 from astropy.time import Time
 from traitlets.config import Config
 
@@ -13,7 +15,12 @@ from ctapipe.calib.camera.gainselection import ThresholdGainSelector
 from ctapipe.instrument.camera.geometry import UnknownPixelShapeWarning
 from ctapipe.instrument.optics import ReflectorShape
 from ctapipe.io import DataLevel
-from ctapipe.io.simteleventsource import SimTelEventSource, apply_simtel_r1_calibration
+from ctapipe.io.simteleventsource import (
+    AtmosphereProfileKind,
+    SimTelEventSource,
+    apply_simtel_r1_calibration,
+    read_atmosphere_profile_from_simtel,
+)
 from ctapipe.utils import get_dataset_path
 
 gamma_test_large_path = get_dataset_path("gamma_test_large.simtel.gz")
@@ -515,3 +522,72 @@ def test_simtel_no_metadata(monkeypatch):
 
         assert all([t.camera.name.startswith("UNKNOWN") for t in subarray.tel.values()])
         assert all([t.optics.name.startswith("UNKNOWN") for t in subarray.tel.values()])
+
+
+def test_load_atmosphere_from_simtel(prod5_gamma_simtel_path):
+    """
+    Load atmosphere from a SimTelEventSource
+    """
+    from ctapipe.atmosphere import (
+        FiveLayerAtmosphereDensityProfile,
+        TableAtmosphereDensityProfile,
+    )
+
+    profile = read_atmosphere_profile_from_simtel(
+        prod5_gamma_simtel_path, kind=AtmosphereProfileKind.AUTO
+    )
+    assert isinstance(profile, TableAtmosphereDensityProfile)
+
+    profile = read_atmosphere_profile_from_simtel(
+        prod5_gamma_simtel_path, kind=AtmosphereProfileKind.TABLE
+    )
+    assert isinstance(profile, TableAtmosphereDensityProfile)
+
+    profile = read_atmosphere_profile_from_simtel(
+        prod5_gamma_simtel_path, kind=AtmosphereProfileKind.FIVELAYER
+    )
+    assert isinstance(profile, FiveLayerAtmosphereDensityProfile)
+
+    # old simtel files don't have the profile in them, so a null list should be
+    # returned
+    simtel_path_old = get_dataset_path("gamma_test_large.simtel.gz")
+    profile = read_atmosphere_profile_from_simtel(simtel_path_old)
+    assert not profile
+
+
+def test_atmosphere_profile(prod5_gamma_simtel_path):
+    """check that for a file with a profile in it that we get it back"""
+    from ctapipe.atmosphere import AtmosphereDensityProfile
+
+    with SimTelEventSource(prod5_gamma_simtel_path) as source:
+        assert isinstance(source.atmosphere_density_profile, AtmosphereDensityProfile)
+
+
+@pytest.mark.parametrize("sign", (-1, 1))
+def test_float32_pihalf(sign):
+    float32_pihalf = np.float32(sign * np.pi / 2)
+    tracking_position = {"azimuth_raw": 0, "altitude_raw": float32_pihalf}
+    pointing = SimTelEventSource._fill_event_pointing(tracking_position)
+    # check that we changed the value to float64 pi/2 to avoid astropy error
+    assert pointing.altitude.value == sign * np.pi / 2
+    # check we can create a Latitude:
+    Latitude(pointing.altitude.value, u.rad)
+
+    event = {
+        "mc_shower": {
+            "energy": 1.0,
+            "altitude": float32_pihalf,
+            "azimuth": 0.0,
+            "h_first_int": 20e3,
+            "xmax": 350,
+            "primary_id": 1,
+        },
+        "mc_event": {
+            "xcore": 0.0,
+            "ycore": 50.0,
+        },
+    }
+    shower = SimTelEventSource._fill_simulated_event_information(event)
+    assert shower.alt.value == sign * np.pi / 2
+    # check we cana create a Latitude:
+    Latitude(shower.alt.value, u.rad)
