@@ -38,7 +38,7 @@ if __name__ == "__main__":
     print("Now setting values")
     ad.telescopes.set_linewidth(0)
     for ii in range(50):
-        vals = np.random.uniform(100.0, size=subarray.num_tels)
+        vals = np.random.uniform(100.0, size=subarray.n_tels)
         ad.values = vals
         plt.pause(0.01)
 
