@@ -8,7 +8,7 @@ from matplotlib.colors import PowerNorm
 from matplotlib.style import use
 
 from ctapipe.image import toymodel
-from ctapipe.instrument import CameraGeometry
+from ctapipe.instrument import SubarrayDescription
 from ctapipe.visualization import CameraDisplay
 
 if __name__ == "__main__":
@@ -16,15 +16,24 @@ if __name__ == "__main__":
     use("ggplot")
     # load the camera
     fig, axs = plt.subplots(1, 3, figsize=(15, 5))
-    geom = CameraGeometry.from_name("LSTCam")
+    subarray = SubarrayDescription.read("dataset://gamma_prod5.simtel.zst")
+    geom = subarray.tel[1].camera.geometry
 
     titles = "Linear Scale", "Log-Scale", "PowerNorm(gamma=2)"
 
     model = toymodel.Gaussian(
-        x=0.2 * u.m, y=0.0 * u.m, width=0.05 * u.m, length=0.15 * u.m, psi="35d",
+        x=0.2 * u.m,
+        y=0.0 * u.m,
+        width=0.05 * u.m,
+        length=0.15 * u.m,
+        psi="35d",
     )
 
-    image, sig, bg = model.generate_image(geom, intensity=1500, nsb_level_pe=5,)
+    image, sig, bg = model.generate_image(
+        geom,
+        intensity=1500,
+        nsb_level_pe=5,
+    )
 
     disps = []
     for ax, title in zip(axs, titles):
